@@ -17,28 +17,18 @@ use constant {
 use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
-use Module::Load::Conditional qw(can_load);
 
-my $Modules = {
+our $Modules = {
     'Data::Printer'        => 0,
     'Data::Dumper::Simple' => 0,
-    'Data::Dumper'         => 0
+    'Data::Dumper'         => 0,
 };
-if (can_load('modules' => { 'Data::Printer' => 0.30 },'autoload' => TRUE)) {
-    $Modules->{'Data::Printer'}++;
-} elsif (can_load('modules' => { 'Data::Dumper::Simple' => 0.10 },'autoload' => TRUE)) {
-    $Modules->{'Data::Dumper::Simple'}++;
-} else {
-    can_load('modules' => { 'Data::Dumper' => 0 },'autoload' => TRUE);
-    $Modules->{'Data::Dumper'}++;
-}
-
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 0.30;
+    our $VERSION = 0.31;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -47,7 +37,32 @@ BEGIN {
     our @EXPORT = qw();
 
     # Functions and variables which can be optionally exported
-    our @EXPORT_OK = qw(@Levels);
+    our @EXPORT_OK = qw(@Levels $Modules);
+    # First we try to load in Data::Printer, then Data::Dumper::Simple, else Data::Dumper
+    my $dp = eval {
+        require Data::Printer;
+        Data::Printer->import();
+        1;
+    };
+    if ($dp) {
+        $Modules->{'Data::Printer'} => 1;
+    } else {
+        my $dds = eval {
+            require Data::Dumper::Simple;
+            Data::Dumper::Simple->import();
+            1;
+        };
+        if ($dds) {
+            $Modules->{'Data::Dumper::Simple'} => 1;
+        } else {
+            eval {
+                require Data::Dumper;
+                Data::Dumper->import();
+            };
+        }
+    }
+    
+
 } ## end BEGIN
 
 # Not used, but optionally exported if the coder wants to use it as some sort
@@ -60,7 +75,7 @@ my $MASTERSTART = time;                   # Script start timestamp.
 
 =head1 NAME
 
-Debug::Easy - A Handy Debugging Module
+Debug::Easy - A Handy Debugging Module With Colorized Output and Formatting
 
 =head1 SYNOPSIS
 
@@ -84,7 +99,7 @@ Debug::Easy - A Handy Debugging Module
  #              Logging headings and goes to STDOUT instead of STDERR.
  #              Very useful for verbose modes in your scripts.
  #  DEBUG     = Level 1 Debugging messages
- #  DEBUGMAX  = Level 2 Debugging messages
+ #  DEBUGMAX  = Level 2 Debugging messages (typically more terse)
  #
  # The third parameter is either a string or a reference to an array
  # of strings to output as multiple lines.  If one of the array
@@ -141,6 +156,20 @@ It is essentially a smart wrapper on top of Log::Fast to enhance it.
  A simple list of all the acceptable debug levels to pass to the {debug} method,
  and the {new} method.
 
+=head2 $Modules
+
+ A hash reference indicating which of three data dumping modules it has
+ detected and loaded.  The keys are the names of the modules, and the
+ value is boolean, either 1 or 0:
+
+=over 1
+
+Data::Printer
+Data::Dumper::Simple
+Data::Dumper
+
+=back
+
 =cut
 
 END {    # We spit out one last message before we die, the total execute time.
@@ -552,7 +581,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 0.30    (March 31, 2015)
+Version 0.31    (April 06, 2015)
 
 =head1 BUGS
 
